@@ -1436,6 +1436,9 @@ class DatasetCollection:
     def __getitem__(self, key):
         return self.store[key]
 
+    def __setitem__(self, key, value):
+        self.store[key] = value
+
     @classmethod
     def register_plugin(cls, plugin_name, plugin):
         setattr(cls, plugin_name, plugin)
